@@ -1,3 +1,10 @@
+# *****************************************************************************
+#
+# Copyright (c) 2020, the ipyregulartable authors.
+#
+# This file is part of the jupyterlab_templates library, distributed under the terms of
+# the Apache License 2.0.  The full license can be found in the LICENSE file.
+#
 import numpy as np
 import string
 from random import choice, sample, randint, random
@@ -13,7 +20,7 @@ def _generateRandomData(n_rows=100, n_cols=10):
             {
                 int: randint(0, 100),
                 str: ''.join(sample(string.ascii_lowercase, 5)),
-                float: random() * 100,
+                float: (random() * 100) - 50,
                 bool: choice((True, False))
             }.get(coltypes[_]) for _ in range(n_cols - 1)
         ]) for _ in range(n_rows)
